tests.test\_simple\_interface\_emulator module
==============================================

.. automodule:: tests.test_simple_interface_emulator
   :members:
   :undoc-members:
   :show-inheritance:
